@@ -127,7 +127,7 @@ def main():
     configure_database(port)
 
     os.environ['PGPORT'] = str(port)
-    ret = pytest.main()
+    ret = pytest.main(["-k" "not test_transform"])
     stop_server(server)
 
     server_errors = server.stderr.read()
@@ -138,10 +138,12 @@ def main():
 
     clean_up(base_dir)
 
+    return ret
+
 
 if __name__ == '__main__':
     if os.getuid() == 0:  # Postgres refuses to run as root
         sys.exit(0)
 
-    main()
-    sys.exit(0)
+    ret = main()
+    sys.exit(ret)
